package sshwrapper

import (
	"fmt"
	"log"
	"os"
	"os/exec"
	"time"
)

// ConnOpts are used for the ssh connection
type ConnOpts struct {
	Hostname       string
	Port           int
	Login          string
	PrivateKeyPath string
	RemotePort     int
	// Reconnect is the interval time for the connection check, default 5 seconds
	Reconnect time.Duration
}

func (o *ConnOpts) Verify() string {
	if o.Login == "" || o.Port == 0 || o.RemotePort == 0 || o.PrivateKeyPath == "" ||
		o.Hostname == "" {
		return "missing required ssh connection options"
	}
	if _, err := os.Stat(o.PrivateKeyPath); os.IsNotExist(err) {
		return fmt.Sprintf("private key %s does not exist or isn't readable", o.PrivateKeyPath)
	}
	return ""
}

// Returns the ssh command template for the connection credentials
func (o *ConnOpts) CommandBase() []string {
	path, err := exec.LookPath("ssh")
	if err != nil {
		log.Panicln(err)
	}
	return []string{
		path,
		"-l",
		o.Login,
		"-o",
		fmt.Sprintf("IdentityFile=%s", o.PrivateKeyPath),
		"-o",
		"StrictHostKeyChecking=accept-new",
		"-o",
		"ControlMaster=no",
		"-o",
		"ControlPath=none",
		"-o",
		"ControlPersist=no",
		"-o",
		"ServerAliveInterval=60",
		"-p",
		fmt.Sprintf("%d", o.Port),
		o.Hostname,
	}
}
